==> nextcloud-app-deck-1%3A0.6.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/pt_PT.js <==
OC.L10N.register(
    "deck",
    {
    "Remove user from card" : "Remover utilizador do cartão",
    "Hours" : "Horas",
    "Minutes" : "Minutos",
    "Deck" : "Baralho",
    "The card \"%s\" on \"%s\" has reached its due date." : "O cartão \"%s\" em \"%s\" chegou a sua data de vencimento",
    "The board \"%s\" has been shared with you by %s." : "O quadro \"%s\" foi partilhado consigo por %s.",
    "{user} has shared the board %s with you." : "{user} partilhou o quadro %s consigo.",
    "Finished" : "Terminado",
    "To review" : "A rever",
    "Action needed" : "Acção necessária",
    "Later" : "Mais tarde",
    "Add a new stack" : "Adicionar nova pilha",
    "Show archived cards" : "Mostrar cartões arquivados",
    "Hide archived cards" : "Esconder cartões arquivados",
    "All Boards" : "Todos os quadros",
    "Archived boards" : "Quadros arquivados",
    "Enter a card title" : "Insira um título para o cartão",
    "Add card" : "Adicionar um cartão",
    "Close" : "Fechar",
    "Sharing" : "Partilha",
    "Tags" : "Etiquetas",
    "Select users or groups to share with" : "Seleccionar utilizadores ou grupos para partilhar com",
    "Loading" : "A carregar",
    "Edit" : "Editar",
    "Share" : "Partilhar",
    "Manage" : "Gerir",
    "Create" : "Criar",
    "Create a new tag" : "Criar uma nova etiqueta",
    "Status" : "Estado",
    "Title" : "Título ",
    "Members" : "Membros",
    "More actions" : "Mais acções",
    "Edit board" : "Editar quadro",
    "Archive board" : "Arquivar quadro",
    "Delete board" : "Eliminar quadro",
    "Create new board" : "Criar novo quadro",
    "New board title" : "Novo título de quadro",
    "by" : "por",
    "Modified:" : "Modificado:",
    "Created:" : "Criado:",
    "Choose a tag" : "Escolher etiqueta",
    "Add a tag" : "Adicionar uma etiqueta",
    "Description" : "Descrição",
    "Saved" : "Guardado",
    "Create a new board" : "Criar um novo quadro"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A0.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/pt_PT.js <==
OC.L10N.register(
    "deck",
    {
    "Remove user from card" : "Remover utilizador do cartão",
    "Hours" : "Horas",
    "Minutes" : "Minutos",
    "File already exists" : "O ficheiro já existe",
    "Deck" : "Baralho",
    "Personal" : "Pessoal",
    "The card \"%s\" on \"%s\" has reached its due date." : "O cartão \"%s\" em \"%s\" chegou a sua data de vencimento",
    "The board \"%s\" has been shared with you by %s." : "O quadro \"%s\" foi partilhado consigo por %s.",
    "{user} has shared the board %s with you." : "{user} partilhou o quadro %s consigo.",
    "Finished" : "Terminado",
    "To review" : "A rever",
    "Action needed" : "Acção necessária",
    "Later" : "Mais tarde",
    "Done" : "Concluído",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro carregado excede a directiva upload_max_filesize no php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro carregado excedo a directiva MAX_FILE_SIZE especificada no formulário HTML",
    "No file was uploaded" : "O ficheiro foi carregado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Add a new stack" : "Adicionar nova pilha",
    "Submit" : "Submeter",
    "Show archived cards" : "Mostrar cartões arquivados",
    "Hide archived cards" : "Esconder cartões arquivados",
    "All Boards" : "Todos os quadros",
    "Archived boards" : "Quadros arquivados",
    "Actions" : "Ações",
    "Archive card" : "Arquivar cartão",
    "Delete card" : "Eliminar cartão",
    "Enter a card title" : "Insira um título para o cartão",
    "Add card" : "Adicionar um cartão",
    "Close" : "Fechar",
    "Sharing" : "Partilha",
    "Tags" : "Etiquetas",
    "Select users or groups to share with" : "Seleccionar utilizadores ou grupos para partilhar com",
    "Group" : "Grupo",
    "Circle" : "Círculo",
    "Loading" : "A carregar",
    "Edit" : "Editar",
    "Share" : "Partilhar",
    "Manage" : "Gerir",
    "Create" : "Criar",
    "Create a new tag" : "Criar uma nova etiqueta",
    "Status" : "Estado",
    "Title" : "Título ",
    "Members" : "Membros",
    "More actions" : "Mais acções",
    "Edit board" : "Editar quadro",
    "Archive board" : "Arquivar quadro",
    "Delete board" : "Eliminar quadro",
    "Create new board" : "Criar novo quadro",
    "New board title" : "Novo título de quadro",
    "Create board" : "Criar quadro",
    "Cancel upload" : "Cancelar envio",
    "by" : "por",
    "Modified:" : "Modificado:",
    "Created:" : "Criado:",
    "Choose a tag" : "Escolher etiqueta",
    "Add a tag" : "Adicionar uma etiqueta",
    "Assign users" : "Atribuir utilizadores",
    "Due date" : "Data limite",
    "Description" : "Descrição",
    "Attachments" : "Anexos",
    "Saved" : "Guardado",
    "Unsaved changes" : "Modificações não guardadas",
    "Create a new board" : "Criar um novo quadro",
    "Settings" : "Definições"
},
"nplurals=2; plural=(n != 1);");
